@@ -4,4 +4,7 @@ R = Dict[str, Any]
 RS = List[R]
 FN = List[str]
 KW = Dict[str, Any]
-PF = Callable[[str], Any]
+FP = Callable[[str], Any]
+DFP = Dict[str, List[FP]]
+RP = Callable[[R], Any]
+LRP = List[RP]
